@@ -12,7 +12,8 @@
 #include "qnaturalsorting.h"
 #include "db_helper.h"
 
-#include "compressed_archive.h"
+#include "initial_comic_info_extractor.h"
+#include "xml_info_parser.h"
 #include "comic.h"
 #include "pdf_comic.h"
 #include "yacreader_global.h"
@@ -20,7 +21,9 @@
 #include "QsLog.h"
 
 #include <algorithm>
+
 using namespace std;
+using namespace YACReader;
 
 //--------------------------------------------------------------------------------
 LibraryCreator::LibraryCreator()
@@ -53,12 +56,12 @@ void LibraryCreator::updateFolder(const QString &source, const QString &target,
     relativeFolderPath = relativeFolderPath.remove(QDir::cleanPath(source));
 
     if (relativeFolderPath.startsWith("/")) {
-        relativeFolderPath = relativeFolderPath.remove(0, 1); //remove firts '/'
+        relativeFolderPath = relativeFolderPath.remove(0, 1); // remove firts '/'
     }
 
     QStringList folders;
 
-    if (!relativeFolderPath.isEmpty()) //updating root
+    if (!relativeFolderPath.isEmpty()) // updating root
     {
         folders = relativeFolderPath.split('/');
     }
@@ -92,7 +95,7 @@ void LibraryCreator::processLibrary(const QString &source, const QString &target
     _source = source;
     _target = target;
     if (DataBaseManagement::checkValidDB(target + "/library.ydb") == "") {
-        //se limpia el directorio ./yacreaderlibrary
+        // se limpia el directorio ./yacreaderlibrary
         QDir d(target);
         d.removeRecursively();
         _mode = CREATOR;
@@ -105,8 +108,8 @@ void LibraryCreator::processLibrary(const QString &source, const QString &target
 void LibraryCreator::run()
 {
     stopRunning = false;
-#ifndef use_unarr
-//check for 7z lib
+#if !defined use_unarr && !defined use_libarchive
+// check for 7z lib
 #if defined Q_OS_UNIX && !defined Q_OS_MAC
     QLibrary *sevenzLib = new QLibrary(QString(LIBDIR) + "/p7zip/7z.so");
 #else
@@ -114,7 +117,7 @@ void LibraryCreator::run()
 #endif
 
     if (!sevenzLib->load()) {
-        QLOG_ERROR() << "Loading 7z.dll : " + sevenzLib->errorString() << endl;
+        QLOG_ERROR() << "Loading 7z.dll : " + sevenzLib->errorString() << Qt::endl;
         QCoreApplication::exit(YACReader::SevenZNotFound);
         exit();
     }
@@ -124,11 +127,11 @@ void LibraryCreator::run()
         QLOG_INFO() << "Starting to create new library ( " << _source << "," << _target << ")";
         _currentPathFolders.clear();
         _currentPathFolders.append(Folder(1, 1, "root", "/"));
-        //se crean los directorios .yacreaderlibrary y .yacreaderlibrary/covers
+        // se crean los directorios .yacreaderlibrary y .yacreaderlibrary/covers
         QDir dir;
         dir.mkpath(_target + "/covers");
 
-        //se crea la base de datos .yacreaderlibrary/library.ydb
+        // se crea la base de datos .yacreaderlibrary/library.ydb
         {
             auto _database = DataBaseManagement::createDatabase("library", _target); //
             _databaseConnection = _database.connectionName();
@@ -142,7 +145,7 @@ void LibraryCreator::run()
 
             /*QSqlQuery pragma("PRAGMA foreign_keys = ON",_database);*/
             _database.transaction();
-            //se crea la librería
+            // se crea la librería
             create(QDir(_source));
 
             DBHelper::updateChildrenInfo(_database);
@@ -173,6 +176,7 @@ void LibraryCreator::run()
                 return;
             }
             QSqlQuery pragma("PRAGMA foreign_keys = ON", _database);
+            pragma.exec();
             _database.transaction();
 
             if (partialUpdate) {
@@ -181,9 +185,10 @@ void LibraryCreator::run()
                 update(QDir(_source));
             }
 
-            if (partialUpdate)
-                DBHelper::updateChildrenInfo(folderDestinationModelIndex.data(FolderModel::IdRole).toULongLong(), _database);
-            else
+            if (partialUpdate) {
+                auto folder = DBHelper::updateChildrenInfo(folderDestinationModelIndex.data(FolderModel::IdRole).toULongLong(), _database);
+                DBHelper::propagateFolderUpdatesToParent(folder, _database);
+            } else
                 DBHelper::updateChildrenInfo(_database);
 
             _database.commit();
@@ -192,21 +197,21 @@ void LibraryCreator::run()
 
         QSqlDatabase::removeDatabase(_databaseConnection);
 
-        //si estabamos en modo creación, se está añadiendo una librería que ya existía y se ha actualizado antes de añadirse.
+        // si estabamos en modo creación, se está añadiendo una librería que ya existía y se ha actualizado antes de añadirse.
         if (!partialUpdate) {
             if (!creation) {
-                emit(updated());
+                emit updated();
             } else {
-                emit(created());
+                emit created();
             }
         }
         QLOG_INFO() << "Update library END";
     }
-    //msleep(100);//TODO try to solve the problem with the udpate dialog (ya no se usa más...)
+    // msleep(100);//TODO try to solve the problem with the udpate dialog (ya no se usa más...)
     if (partialUpdate) {
         emit updatedCurrentFolder(folderDestinationModelIndex);
         emit finished();
-    } else //TODO check this part!!
+    } else // TODO check this part!!
         emit finished();
     creation = false;
 }
@@ -217,7 +222,7 @@ void LibraryCreator::stop()
     stopRunning = true;
 }
 
-//retorna el id del ultimo de los folders
+// retorna el id del ultimo de los folders
 qulonglong LibraryCreator::insertFolders()
 {
     auto _database = QSqlDatabase::database(_databaseConnection);
@@ -228,7 +233,7 @@ qulonglong LibraryCreator::insertFolders()
         if (!(i->knownId)) {
             i->setFather(currentId);
             i->setManga(currentParent.isManga());
-            currentId = DBHelper::insert(&(*i), _database); //insertFolder(currentId,*i);
+            currentId = DBHelper::insert(&(*i), _database); // insertFolder(currentId,*i);
             i->setId(currentId);
         } else {
             currentId = i->id;
@@ -262,10 +267,10 @@ void LibraryCreator::create(QDir dir)
 #endif
         if (fileInfo.isDir()) {
             QLOG_TRACE() << "Parsing folder" << fileInfo.canonicalPath();
-            //se añade al path actual el folder, aún no se sabe si habrá que añadirlo a la base de datos
+            // se añade al path actual el folder, aún no se sabe si habrá que añadirlo a la base de datos
             _currentPathFolders.append(Folder(fileInfo.fileName(), relativePath));
             create(QDir(fileInfo.absoluteFilePath()));
-            //una vez importada la información del folder, se retira del path actual ya que no volverá a ser visitado
+            // una vez importada la información del folder, se retira del path actual ya que no volverá a ser visitado
             _currentPathFolders.pop_back();
         } else {
             QLOG_TRACE() << "Parsing file" << fileInfo.filePath();
@@ -282,32 +287,37 @@ bool LibraryCreator::checkCover(const QString &hash)
 void LibraryCreator::insertComic(const QString &relativePath, const QFileInfo &fileInfo)
 {
     auto _database = QSqlDatabase::database(_databaseConnection);
-    //Se calcula el hash del cómic
+    // Se calcula el hash del cómic
 
     QCryptographicHash crypto(QCryptographicHash::Sha1);
     QFile file(fileInfo.absoluteFilePath());
     file.open(QFile::ReadOnly);
     crypto.addData(file.read(524288));
     file.close();
-    //hash Sha1 del primer 0.5MB + filesize
+    // hash Sha1 del primer 0.5MB + filesize
     QString hash = QString(crypto.result().toHex().constData()) + QString::number(fileInfo.size());
     ComicDB comic = DBHelper::loadComic(fileInfo.fileName(), relativePath, hash, _database);
     int numPages = 0;
     QPair<int, int> originalCoverSize = { 0, 0 };
     bool exists = checkCover(hash);
+
+    YACReader::InitialComicInfoExtractor ie(QDir::cleanPath(fileInfo.absoluteFilePath()), _target + "/covers/" + hash + ".jpg", comic.info.coverPage.toInt());
+
     if (!(comic.hasCover() && exists)) {
-        ThumbnailCreator tc(QDir::cleanPath(fileInfo.absoluteFilePath()), _target + "/covers/" + hash + ".jpg", comic.info.coverPage.toInt());
-        tc.create();
-        numPages = tc.getNumPages();
-        originalCoverSize = tc.getOriginalCoverSize();
+        ie.extract();
+        numPages = ie.getNumPages();
+        originalCoverSize = ie.getOriginalCoverSize();
         if (numPages > 0) {
             emit(comicAdded(relativePath, _target + "/covers/" + hash + ".jpg"));
         }
     }
 
     if (numPages > 0 || exists) {
-        //en este punto sabemos que todos los folders que hay en _currentPath, deberían estar añadidos a la base de datos
+        // en este punto sabemos que todos los folders que hay en _currentPath, deberían estar añadidos a la base de datos
         insertFolders();
+
+        bool parsed = YACReader::parseXMLIntoInfo(ie.getXMLInfoRawData(), comic.info);
+
         comic.info.numPages = numPages;
         if (originalCoverSize.second > 0) {
             comic.info.originalCoverSize = QString("%1x%2").arg(originalCoverSize.first).arg(originalCoverSize.second);
@@ -316,15 +326,16 @@ void LibraryCreator::insertComic(const QString &relativePath, const QFileInfo &f
 
         comic.parentId = _currentPathFolders.last().id;
         comic.info.manga = _currentPathFolders.last().isManga();
-        DBHelper::insert(&comic, _database);
+
+        DBHelper::insert(&comic, _database, parsed);
     }
 }
 
 void LibraryCreator::update(QDir dirS)
 {
     auto _database = QSqlDatabase::database(_databaseConnection);
-    //QLOG_TRACE() << "Updating" << dirS.absolutePath();
-    //QLOG_TRACE() << "Getting info from dir" << dirS.absolutePath();
+    // QLOG_TRACE() << "Updating" << dirS.absolutePath();
+    // QLOG_TRACE() << "Getting info from dir" << dirS.absolutePath();
     dirS.setNameFilters(_nameFilter);
     dirS.setFilter(QDir::AllDirs | QDir::NoDotAndDotDot);
     dirS.setSorting(QDir::Name | QDir::IgnoreCase | QDir::LocaleAware);
@@ -339,57 +350,63 @@ void LibraryCreator::update(QDir dirS)
     QFileInfoList listS;
     listS.append(listSFolders);
     listS.append(listSFiles);
-    //QLOG_DEBUG() << "---------------------------------------------------------";
-    //foreach(QFileInfo info,listS)
+    // QLOG_DEBUG() << "---------------------------------------------------------";
+    // foreach(QFileInfo info,listS)
     //	QLOG_DEBUG() << info.fileName();
 
-    //QLOG_TRACE() << "END Getting info from dir" << dirS.absolutePath();
+    // QLOG_TRACE() << "END Getting info from dir" << dirS.absolutePath();
 
-    //QLOG_TRACE() << "Getting info from DB" << dirS.absolutePath();
+    // QLOG_TRACE() << "Getting info from DB" << dirS.absolutePath();
     QList<LibraryItem *> folders = DBHelper::getFoldersFromParent(_currentPathFolders.last().id, _database);
     QList<LibraryItem *> comics = DBHelper::getComicsFromParent(_currentPathFolders.last().id, _database);
-    //QLOG_TRACE() << "END Getting info from DB" << dirS.absolutePath();
+    // QLOG_TRACE() << "END Getting info from DB" << dirS.absolutePath();
 
     QList<LibraryItem *> listD;
     std::sort(folders.begin(), folders.end(), naturalSortLessThanCILibraryItem);
     std::sort(comics.begin(), comics.end(), naturalSortLessThanCILibraryItem);
     listD.append(folders);
     listD.append(comics);
-    //QLOG_DEBUG() << "---------------------------------------------------------";
-    //foreach(LibraryItem * info,listD)
+    // QLOG_DEBUG() << "---------------------------------------------------------";
+    // foreach(LibraryItem * info,listD)
     //	QLOG_DEBUG() << info->name;
-    //QLOG_DEBUG() << "---------------------------------------------------------";
+    // QLOG_DEBUG() << "---------------------------------------------------------";
     int lenghtS = listS.size();
     int lenghtD = listD.size();
-    //QLOG_DEBUG() << "S len" << lenghtS << "D len" << lenghtD;
-    //QLOG_DEBUG() << "---------------------------------------------------------";
+    // QLOG_DEBUG() << "S len" << lenghtS << "D len" << lenghtD;
+    // QLOG_DEBUG() << "---------------------------------------------------------";
 
     bool updated;
     int i, j;
     for (i = 0, j = 0; (i < lenghtS) || (j < lenghtD);) {
-        if (stopRunning)
+        if (stopRunning) {
+            qDeleteAll(listD);
             return;
+        }
         updated = false;
-        if (i >= lenghtS) //finished source files/dirs
+        if (i >= lenghtS) // finished source files/dirs
         {
-            //QLOG_WARN() << "finished source files/dirs" << dirS.absolutePath();
-            //delete listD //from j
+            // QLOG_WARN() << "finished source files/dirs" << dirS.absolutePath();
+            // delete listD //from j
             for (; j < lenghtD; j++) {
-                if (stopRunning)
+                if (stopRunning) {
+                    qDeleteAll(listD);
                     return;
+                }
                 DBHelper::removeFromDB(listD.at(j), (_database));
             }
             updated = true;
         }
-        if (j >= lenghtD) //finished library files/dirs
+        if (j >= lenghtD) // finished library files/dirs
         {
-            //QLOG_WARN() << "finished library files/dirs" << dirS.absolutePath();
-            //create listS //from i
+            // QLOG_WARN() << "finished library files/dirs" << dirS.absolutePath();
+            // create listS //from i
             for (; i < lenghtS; i++) {
-                if (stopRunning)
+                if (stopRunning) {
+                    qDeleteAll(listD);
                     return;
+                }
                 QFileInfo fileInfoS = listS.at(i);
-                if (fileInfoS.isDir()) //create folder
+                if (fileInfoS.isDir()) // create folder
                 {
 #ifdef Q_OS_MAC
                     QStringList src = _source.split("/");
@@ -402,10 +419,10 @@ void LibraryCreator::update(QDir dirS)
 #else
                     QString path = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source);
 #endif
-                    _currentPathFolders.append(Folder(fileInfoS.fileName(), path)); //folder actual no está en la BD
+                    _currentPathFolders.append(Folder(fileInfoS.fileName(), path)); // folder actual no está en la BD
                     create(QDir(fileInfoS.absoluteFilePath()));
                     _currentPathFolders.pop_back();
-                } else //create comic
+                } else // create comic
                 {
 #ifdef Q_OS_MAC
                     QStringList src = _source.split("/");
@@ -427,23 +444,23 @@ void LibraryCreator::update(QDir dirS)
         if (!updated) {
             QFileInfo fileInfoS = listS.at(i);
             LibraryItem *fileInfoD = listD.at(j);
-            QString nameS = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(QDir::cleanPath(fileInfoS.absolutePath())); //remove source
+            QString nameS = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(QDir::cleanPath(fileInfoS.absolutePath())); // remove source
             QString nameD = "/" + fileInfoD->name;
 
             int comparation = QString::localeAwareCompare(nameS, nameD);
             if (fileInfoS.isDir() && fileInfoD->isDir())
-                if (comparation == 0) //same folder, update
+                if (comparation == 0) // same folder, update
                 {
-                    _currentPathFolders.append(*static_cast<Folder *>(fileInfoD)); //fileInfoD conoce su padre y su id
+                    _currentPathFolders.append(*static_cast<Folder *>(fileInfoD)); // fileInfoD conoce su padre y su id
                     update(QDir(fileInfoS.absoluteFilePath()));
                     _currentPathFolders.pop_back();
                     i++;
                     j++;
-                } else if (comparation < 0) //nameS doesn't exist on DB
+                } else if (comparation < 0) // nameS doesn't exist on DB
                 {
 
                     if (nameS != "/.yacreaderlibrary") {
-                        //QLOG_WARN() << "dir source < dest" << nameS << nameD;
+                        // QLOG_WARN() << "dir source < dest" << nameS << nameD;
 #ifdef Q_OS_MAC
                         QStringList src = _source.split("/");
                         QString filePath = fileInfoS.absoluteFilePath();
@@ -460,222 +477,84 @@ void LibraryCreator::update(QDir dirS)
                         _currentPathFolders.pop_back();
                     }
                     i++;
-                } else //nameD no longer available on Source folder...
+                } else // nameD no longer available on Source folder...
                 {
                     if (nameS != "/.yacreaderlibrary") {
-                        //QLOG_WARN() << "dir source > dest" << nameS << nameD;
+                        // QLOG_WARN() << "dir source > dest" << nameS << nameD;
                         DBHelper::removeFromDB(fileInfoD, _database);
                         j++;
                     } else
-                        i++; //skip library directory
+                        i++; // skip library directory
                 }
             else // one of them(or both) is a file
-                    if (fileInfoS.isDir()) //this folder doesn't exist on library
-            {
-                if (nameS != "/.yacreaderlibrary") //skip .yacreaderlibrary folder
+                if (fileInfoS.isDir()) // this folder doesn't exist on library
                 {
-                    //QLOG_WARN() << "one of them(or both) is a file" << nameS << nameD;
-#ifdef Q_OS_MAC
-                    QStringList src = _source.split("/");
-                    QString filePath = fileInfoS.absoluteFilePath();
-                    QStringList fp = filePath.split("/");
-                    for (int i = 0; i < src.count(); i++) {
-                        fp.removeFirst();
-                    }
-                    QString path = "/" + fp.join("/");
-#else
-                    QString path = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source);
-#endif
-                    _currentPathFolders.append(Folder(fileInfoS.fileName(), path));
-                    create(QDir(fileInfoS.absoluteFilePath()));
-                    _currentPathFolders.pop_back();
-                }
-                i++;
-            } else if (fileInfoD->isDir()) //delete this folder from library
-            {
-                DBHelper::removeFromDB(fileInfoD, _database);
-                j++;
-            } else //both are files  //BUG on windows (no case sensitive)
-            {
-                //nameD.remove(nameD.size()-4,4);
-                int comparation = QString::localeAwareCompare(nameS, nameD);
-                if (comparation < 0) //create new thumbnail
-                {
-#ifdef Q_OS_MAC
-                    QStringList src = _source.split("/");
-                    QString filePath = fileInfoS.absoluteFilePath();
-                    QStringList fp = filePath.split("/");
-                    for (int i = 0; i < src.count(); i++) {
-                        fp.removeFirst();
-                    }
-                    QString path = "/" + fp.join("/");
-#else
-                    QString path = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source);
-#endif
-                    insertComic(path, fileInfoS);
-                    i++;
-                } else {
-                    if (comparation > 0) //delete thumbnail
+                    if (nameS != "/.yacreaderlibrary") // skip .yacreaderlibrary folder
                     {
-                        DBHelper::removeFromDB(fileInfoD, _database);
-                        j++;
-                    } else //same file
-                    {
-                        if (fileInfoS.isFile() && !fileInfoD->isDir()) {
-                            //TODO comprobar fechas + tamaño
-                            //if(fileInfoS.lastModified()>fileInfoD.lastModified())
-                            //{
-                            //	dirD.mkpath(_target+(QDir::cleanPath(fileInfoS.absolutePath()).remove(_source)));
-                            //	emit(coverExtracted(QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source)));
-                            //	ThumbnailCreator tc(QDir::cleanPath(fileInfoS.absoluteFilePath()),_target+(QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source))+".jpg");
-                            //	tc.create();
-                            //}
+                        // QLOG_WARN() << "one of them(or both) is a file" << nameS << nameD;
+#ifdef Q_OS_MAC
+                        QStringList src = _source.split("/");
+                        QString filePath = fileInfoS.absoluteFilePath();
+                        QStringList fp = filePath.split("/");
+                        for (int i = 0; i < src.count(); i++) {
+                            fp.removeFirst();
                         }
+                        QString path = "/" + fp.join("/");
+#else
+                        QString path = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source);
+#endif
+                        _currentPathFolders.append(Folder(fileInfoS.fileName(), path));
+                        create(QDir(fileInfoS.absoluteFilePath()));
+                        _currentPathFolders.pop_back();
+                    }
+                    i++;
+                } else if (fileInfoD->isDir()) // delete this folder from library
+                {
+                    DBHelper::removeFromDB(fileInfoD, _database);
+                    j++;
+                } else // both are files  //BUG on windows (no case sensitive)
+                {
+                    // nameD.remove(nameD.size()-4,4);
+                    int comparation = QString::localeAwareCompare(nameS, nameD);
+                    if (comparation < 0) // create new thumbnail
+                    {
+#ifdef Q_OS_MAC
+                        QStringList src = _source.split("/");
+                        QString filePath = fileInfoS.absoluteFilePath();
+                        QStringList fp = filePath.split("/");
+                        for (int i = 0; i < src.count(); i++) {
+                            fp.removeFirst();
+                        }
+                        QString path = "/" + fp.join("/");
+#else
+                        QString path = QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source);
+#endif
+                        insertComic(path, fileInfoS);
                         i++;
-                        j++;
+                    } else {
+                        if (comparation > 0) // delete thumbnail
+                        {
+                            DBHelper::removeFromDB(fileInfoD, _database);
+                            j++;
+                        } else // same file
+                        {
+                            if (fileInfoS.isFile() && !fileInfoD->isDir()) {
+                                // TODO comprobar fechas + tamaño
+                                // if(fileInfoS.lastModified()>fileInfoD.lastModified())
+                                //{
+                                //	dirD.mkpath(_target+(QDir::cleanPath(fileInfoS.absolutePath()).remove(_source)));
+                                //	emit(coverExtracted(QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source)));
+                                //	ThumbnailCreator tc(QDir::cleanPath(fileInfoS.absoluteFilePath()),_target+(QDir::cleanPath(fileInfoS.absoluteFilePath()).remove(_source))+".jpg");
+                                //	tc.create();
+                                // }
+                            }
+                            i++;
+                            j++;
+                        }
                     }
                 }
-            }
-        }
-    }
-}
-
-bool ThumbnailCreator::crash = false;
-
-ThumbnailCreator::ThumbnailCreator(QString fileSource, QString target, int coverPage)
-    : _fileSource(fileSource), _target(target), _numPages(0), _coverPage(coverPage)
-{
-}
-
-void ThumbnailCreator::create()
-{
-    QFileInfo fi(_fileSource);
-    if (!fi.exists()) //TODO: error file not found.
-    {
-        _cover.load(":/images/notCover.png");
-        QLOG_WARN() << "Extracting cover: file not found " << _fileSource;
-        return;
-    }
-#ifndef NO_PDF
-    if (fi.suffix().compare("pdf", Qt::CaseInsensitive) == 0) {
-#if defined Q_OS_MAC && defined USE_PDFKIT
-        MacOSXPDFComic *pdfComic = new MacOSXPDFComic();
-        if (!pdfComic->openComic(_fileSource)) {
-            delete pdfComic;
-            //QImage p;
-            //p.load(":/images/notCover.png");
-            //p.save(_target);
-            return;
-        }
-#elif defined USE_PDFIUM
-        auto pdfComic = new PdfiumComic();
-        if (!pdfComic->openComic(_fileSource)) {
-            delete pdfComic;
-            return;
-        }
-#else
-        Poppler::Document *pdfComic = Poppler::Document::load(_fileSource);
-#endif
-
-        if (!pdfComic) {
-            QLOG_WARN() << "Extracting cover: unable to open PDF file " << _fileSource;
-            //delete pdfComic; //TODO check if the delete is needed
-            pdfComic = 0;
-            //QImage p;
-            //p.load(":/images/notCover.png");
-            //p.save(_target);
-            return;
-        }
-#if !defined USE_PDFKIT && !defined USE_PDFIUM
-        //poppler only, not mac
-        if (pdfComic->isLocked()) {
-            QLOG_WARN() << "Extracting cover: unable to open PDF file " << _fileSource;
-            delete pdfComic;
-            return;
-        }
-#endif
-        _numPages = pdfComic->numPages();
-        if (_numPages >= _coverPage) {
-#if defined Q_OS_MAC || defined USE_PDFIUM
-            QImage p = pdfComic->getPage(_coverPage - 1); //TODO check if the page is valid
-#else
-            QImage p = pdfComic->page(_coverPage - 1)->renderToImage(72, 72);
-#endif //
-            _cover = p;
-            _coverSize = QPair<int, int>(p.width(), p.height());
-            if (_target != "") {
-                QImage scaled;
-                if (p.width() > p.height()) //landscape??
-                {
-                    scaled = p.scaledToWidth(640, Qt::SmoothTransformation);
-                } else {
-                    scaled = p.scaledToWidth(480, Qt::SmoothTransformation);
-                }
-                scaled.save(_target, 0, 75);
-            } else if (_target != "") {
-                QLOG_WARN() << "Extracting cover: requested cover index greater than numPages " << _fileSource;
-                //QImage p;
-                //p.load(":/images/notCover.png");
-                //p.save(_target);
-            }
-            delete pdfComic;
-        }
-        return;
-    }
-#endif //NO_PDF
-
-    if (crash) {
-        return;
-    }
-
-    CompressedArchive archive(_fileSource);
-    if (!archive.toolsLoaded()) {
-        QLOG_WARN() << "Extracting cover: 7z lib not loaded";
-        crash = true;
-        return;
-    }
-    if (!archive.isValid()) {
-        QLOG_WARN() << "Extracting cover: file format not supported " << _fileSource;
-    }
-    //se filtran para obtener sólo los formatos soportados
-    QList<QString> order = archive.getFileNames();
-    QList<QString> fileNames = FileComic::filter(order);
-    _numPages = fileNames.size();
-    if (_numPages == 0) {
-        QLOG_WARN() << "Extracting cover: empty comic " << _fileSource;
-        _cover.load(":/images/notCover.png");
-        if (_target != "") {
-            _cover.save(_target);
-        }
-    } else {
-        if (_coverPage > _numPages) {
-            _coverPage = 1;
-        }
-        std::sort(fileNames.begin(), fileNames.end(), naturalSortLessThanCI);
-        int index = order.indexOf(fileNames.at(_coverPage - 1));
-
-        if (_target == "") {
-            if (!_cover.loadFromData(archive.getRawDataAtIndex(index))) {
-                QLOG_WARN() << "Extracting cover: unable to load image from extracted cover " << _fileSource;
-                _cover.load(":/images/notCover.png");
-            }
-        } else {
-            QImage p;
-            if (p.loadFromData(archive.getRawDataAtIndex(index))) {
-                _coverSize = QPair<int, int>(p.width(), p.height());
-                QImage scaled;
-                if (p.width() > p.height()) //landscape??
-                {
-                    scaled = p.scaledToWidth(640, Qt::SmoothTransformation);
-                } else {
-                    scaled = p.scaledToWidth(480, Qt::SmoothTransformation);
-                }
-                scaled.save(_target, 0, 75);
-            } else {
-                QLOG_WARN() << "Extracting cover: unable to load image from extracted cover " << _fileSource;
-                //p.load(":/images/notCover.png");
-                //p.save(_target);
-            }
         }
     }
+
+    qDeleteAll(listD);
 }
