@@ -5,15 +5,14 @@
 
 class NoLibrariesWidget : public QWidget
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	explicit NoLibrariesWidget(QWidget *parent = 0);
-	
+    explicit NoLibrariesWidget(QWidget *parent = nullptr);
+
 signals:
-	void createNewLibrary();
-	void addExistingLibrary();
+    void createNewLibrary();
+    void addExistingLibrary();
 public slots:
-	
 };
 
 #endif // NO_LIBRARIES_WIDGET_H
