@@ -31,7 +31,7 @@ YACReaderComicsViewsManager::YACReaderComicsViewsManager(QSettings *settings, Li
 
     case Grid:
         comicsView = gridComicsView = new GridComicsView();
-        connect(libraryWindow->optionsDialog, SIGNAL(optionsChanged()), gridComicsView, SLOT(updateBackgroundConfig()));
+        connect(libraryWindow->optionsDialog, &YACReaderOptionsDialog::optionsChanged, gridComicsView, &GridComicsView::updateBackgroundConfig);
         comicsViewStatus = Grid;
         break;
 
@@ -58,10 +58,9 @@ YACReaderComicsViewsManager::YACReaderComicsViewsManager(QSettings *settings, Li
 
     comicsViewStack->setCurrentWidget(comicsView);
 
-    //connections
-
-    connect(emptyFolderWidget, SIGNAL(copyComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(copyAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
-    connect(emptyFolderWidget, SIGNAL(moveComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(moveAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
+    // connections
+    connect(emptyFolderWidget, &EmptyFolderWidget::copyComicsToCurrentFolder, libraryWindow, &LibraryWindow::copyAndImportComicsToCurrentFolder);
+    connect(emptyFolderWidget, &EmptyFolderWidget::moveComicsToCurrentFolder, libraryWindow, &LibraryWindow::moveAndImportComicsToCurrentFolder);
 }
 
 QWidget *YACReaderComicsViewsManager::containerWidget()
@@ -80,8 +79,8 @@ void YACReaderComicsViewsManager::showComicsView()
 {
     comicsViewStack->setCurrentWidget(comicsView);
 
-    //BUG, ugly workaround for glitch when QOpenGLWidget (flow) is used just after any other widget in the views stack
-    //Somehow QOpenGLWidget is messing with the rendering of the side bar (wrong buffer swapping)
+    // BUG, ugly workaround for glitch when QOpenGLWidget (flow) is used just after any other widget in the views stack
+    // Somehow QOpenGLWidget is messing with the rendering of the side bar (wrong buffer swapping)
     libraryWindow->sideBar->update();
 }
 
@@ -110,12 +109,12 @@ void YACReaderComicsViewsManager::showNoSearchResultsView()
     comicsViewStack->setCurrentWidget(noSearchResultsWidget);
 }
 
-//TODO recover the current comics selection and restore it in the destination
+// TODO recover the current comics selection and restore it in the destination
 void YACReaderComicsViewsManager::toggleComicsView()
 {
     if (comicsViewStack->currentWidget() == comicsView) {
-        QTimer::singleShot(0, this, SLOT(showComicsViewTransition()));
-        QTimer::singleShot(100, this, SLOT(_toggleComicsView()));
+        QTimer::singleShot(0, this, &YACReaderComicsViewsManager::showComicsViewTransition);
+        QTimer::singleShot(100, this, &YACReaderComicsViewsManager::_toggleComicsView);
     } else {
         _toggleComicsView();
     }
@@ -126,40 +125,40 @@ void YACReaderComicsViewsManager::focusComicsViewViaShortcut()
     comicsView->focusComicsNavigation(Qt::ShortcutFocusReason);
 }
 
-//PROTECTED
+// PROTECTED
 
 void YACReaderComicsViewsManager::disconnectComicsViewConnections(ComicsView *widget)
 {
-    disconnect(widget, SIGNAL(comicRated(int, QModelIndex)), libraryWindow->comicsModel, SLOT(updateRating(int, QModelIndex)));
-    disconnect(libraryWindow->showHideMarksAction, SIGNAL(toggled(bool)), widget, SLOT(setShowMarks(bool)));
-    disconnect(widget, SIGNAL(selected(unsigned int)), libraryWindow, SLOT(openComic()));
-    disconnect(widget, SIGNAL(openComic(ComicDB)), libraryWindow, SLOT(openComic(ComicDB)));
-    disconnect(libraryWindow->selectAllComicsAction, SIGNAL(triggered()), widget, SLOT(selectAll()));
-    disconnect(comicsView, SIGNAL(copyComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(copyAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
-    disconnect(comicsView, SIGNAL(moveComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(moveAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
-    disconnect(comicsView, SIGNAL(customContextMenuViewRequested(QPoint)), libraryWindow, SLOT(showComicsViewContextMenu(QPoint)));
-    disconnect(comicsView, SIGNAL(customContextMenuItemRequested(QPoint)), libraryWindow, SLOT(showComicsItemContextMenu(QPoint)));
+    disconnect(widget, &ComicsView::comicRated, libraryWindow->comicsModel, &ComicModel::updateRating);
+    disconnect(libraryWindow->showHideMarksAction, &QAction::toggled, widget, &ComicsView::setShowMarks);
+    disconnect(widget, &ComicsView::selected, libraryWindow, QOverload<>::of(&LibraryWindow::openComic));
+    disconnect(widget, &ComicsView::openComic, libraryWindow, QOverload<const ComicDB &, const ComicModel::Mode>::of(&LibraryWindow::openComic));
+    disconnect(libraryWindow->selectAllComicsAction, &QAction::triggered, widget, &ComicsView::selectAll);
+    disconnect(comicsView, &ComicsView::copyComicsToCurrentFolder, libraryWindow, &LibraryWindow::copyAndImportComicsToCurrentFolder);
+    disconnect(comicsView, &ComicsView::moveComicsToCurrentFolder, libraryWindow, &LibraryWindow::moveAndImportComicsToCurrentFolder);
+    disconnect(comicsView, &ComicsView::customContextMenuViewRequested, libraryWindow, &LibraryWindow::showComicsViewContextMenu);
+    disconnect(comicsView, &ComicsView::customContextMenuItemRequested, libraryWindow, &LibraryWindow::showComicsItemContextMenu);
 }
 
 void YACReaderComicsViewsManager::doComicsViewConnections()
 {
-    connect(comicsView, SIGNAL(comicRated(int, QModelIndex)), libraryWindow->comicsModel, SLOT(updateRating(int, QModelIndex)));
-    connect(libraryWindow->showHideMarksAction, SIGNAL(toggled(bool)), comicsView, SLOT(setShowMarks(bool)));
-    connect(comicsView, SIGNAL(selected(unsigned int)), libraryWindow, SLOT(openComic()));
-    connect(comicsView, SIGNAL(openComic(const ComicDB &, const ComicModel::Mode)), libraryWindow, SLOT(openComic(const ComicDB &, const ComicModel::Mode)));
+    connect(comicsView, &ComicsView::comicRated, libraryWindow->comicsModel, &ComicModel::updateRating);
+    connect(libraryWindow->showHideMarksAction, &QAction::toggled, comicsView, &ComicsView::setShowMarks);
+    connect(comicsView, &ComicsView::selected, libraryWindow, QOverload<>::of(&LibraryWindow::openComic));
+    connect(comicsView, &ComicsView::openComic, libraryWindow, QOverload<const ComicDB &, const ComicModel::Mode>::of(&LibraryWindow::openComic));
 
-    connect(libraryWindow->selectAllComicsAction, SIGNAL(triggered()), comicsView, SLOT(selectAll()));
+    connect(libraryWindow->selectAllComicsAction, &QAction::triggered, comicsView, &ComicsView::selectAll);
 
-    connect(comicsView, SIGNAL(customContextMenuViewRequested(QPoint)), libraryWindow, SLOT(showComicsViewContextMenu(QPoint)));
-    connect(comicsView, SIGNAL(customContextMenuItemRequested(QPoint)), libraryWindow, SLOT(showComicsItemContextMenu(QPoint)));
-    //Drops
-    connect(comicsView, SIGNAL(copyComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(copyAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
-    connect(comicsView, SIGNAL(moveComicsToCurrentFolder(QList<QPair<QString, QString>>)), libraryWindow, SLOT(moveAndImportComicsToCurrentFolder(QList<QPair<QString, QString>>)));
+    connect(comicsView, &ComicsView::customContextMenuViewRequested, libraryWindow, &LibraryWindow::showComicsViewContextMenu);
+    connect(comicsView, &ComicsView::customContextMenuItemRequested, libraryWindow, &LibraryWindow::showComicsItemContextMenu);
+    // Drops
+    connect(comicsView, &ComicsView::copyComicsToCurrentFolder, libraryWindow, &LibraryWindow::copyAndImportComicsToCurrentFolder);
+    connect(comicsView, &ComicsView::moveComicsToCurrentFolder, libraryWindow, &LibraryWindow::moveAndImportComicsToCurrentFolder);
 }
 
 void YACReaderComicsViewsManager::switchToComicsView(ComicsView *from, ComicsView *to)
 {
-    //setup views
+    // setup views
     disconnectComicsViewConnections(from);
     from->close();
 
@@ -171,9 +170,9 @@ void YACReaderComicsViewsManager::switchToComicsView(ComicsView *from, ComicsVie
     comicsViewStack->removeWidget(from);
     comicsViewStack->addWidget(comicsView);
 
-    //delete from; No need to delete the previews view, because all views are going to be kept in memory
+    // delete from; No need to delete the previews view, because all views are going to be kept in memory
 
-    //load content into current view
+    // load content into current view
     libraryWindow->loadCoversFromCurrentModel();
 
     if (!libraryWindow->searchEdit->text().isEmpty()) {
@@ -200,7 +199,7 @@ void YACReaderComicsViewsManager::_toggleComicsView()
             gridComicsView = new GridComicsView();
 
         switchToComicsView(classicComicsView, gridComicsView);
-        connect(libraryWindow->optionsDialog, SIGNAL(optionsChanged()), gridComicsView, SLOT(updateBackgroundConfig()));
+        connect(libraryWindow->optionsDialog, &YACReaderOptionsDialog::optionsChanged, gridComicsView, &GridComicsView::updateBackgroundConfig);
         comicsViewStatus = Grid;
 
         break;
